!> \file prop_th_icetemp.f90
!! Subroutines for thermal propreties calculation
!<

!> \namespace prop_th_icetemp
!! Subroutines to calculate thermal prop 

!> SUBROUTINE: Thermal_prop_icetemp
!! 
!! Calculate the thermal prop of ice
!!
!! Used modules:
!! - Icetemp_declar
!>

Subroutine Thermal_prop_icetemp
!$ USE OMP_LIB
  use module3d_phy, only: h,t,tpmp
  use runparam, only: itracebug,num_tracebug
  use geography, only: nx,ny,nz
  use icetemp_declar, only: cp,ct 
  use Param_phy_mod, only: ro

  Implicit None

  integer i,j,k

  If (Itracebug.Eq.1) Write(Num_tracebug,*)' Entree Dans Routine Thermal_prop_icetemp'

!$OMP PARALLEL
!$OMP DO COLLAPSE(2)
  Do K=1,Nz  
     Do J=1,Ny
        Do I=1,Nx
           !  Temperature De Fusion:Tpmp (En Deg C)
           !  Capacite Calorifique : Cp En J/Kg/K Puis Multiplie Par Ro En J/M3/K
           !  Conductivite : Ct  En J/M/K/An
           !  Attention Pour La Conductivite C'Est La Formule De Yin-Chao Yen

!           Ct(I,J,K)=6.62E7
!           Cp(I,J,K)=2009. 
           Tpmp(I,J,K)=-0.00087*(K-1)*1./(Nz-1)*H(I,J)!De=1/(Nz_m-1)
           Cp(I,J,K)=(2115.3+7.79293*T(I,J,K)) 
           Cp(I,J,K)=Cp(I,J,K)*Ro              ! En J/M3/K
           Ct(I,J,K)=3.1014e8*Exp(-0.0057*(T(I,J,K)+273.15)) !En J/M/K/An
        End Do
     End Do
  End Do
!$OMP END DO
!$OMP END PARALLEL
End Subroutine Thermal_prop_icetemp

!-----------------------------------------------------------------------------------------------------------

!> SUBROUTINE: Temp_mer
!! Calculate temperature of the sea
!! Used modules:
!! - Icetemp_declar
!>
Subroutine Temp_mer
  use module3D_phy, only: H,flot
  use runparam, only: itracebug,num_tracebug
  use geography, only: nx,ny
  use Icetemp_declar,only: acof1,bcof1,ccof1,tbmer,S0mer
  use Param_phy_mod, only: ro,row

  Implicit None 

  integer :: i,j

  If (Itracebug.Eq.1) Write(Num_tracebug,*)' Entree Dans Routine Temp_mer_icetemp '

  Do J=1,Ny
     Do I=1,Nx
        If (Flot(I,J)) &
             Tbmer(I,J) = Acof1*S0mer + Bcof1 + Ccof1*H(I,J)*Ro/Row
     End Do
  End Do
End Subroutine Temp_mer
